@@ -5,6 +5,6 @@ def add_up(n):
     result = 0;
 
     for i in range(0, n):
-        result = add(result, 1);
+        result = add(result, i);
 
     return result;
